**DAS MEDIDAS CAUTELARES DIVERSAS DA PRISÃO NO LOCAL DO CRIME AMBIENTAL** 

[START_INDENTATION] O Ministério Público requer, ainda, com fundamento no art. 282 e seguintes e art. 319, I, II, IV, VI, do Código de Processo Penal, a aplicação ao suspeito de medida cautelar diversa da prisão, pelas razões a seguir expostas.

O art. 282, do CPP, com a redação dada pela Lei 12.403/2011, traz a seguinte disposição quanto às medidas cautelares diversas da prisão:

> "Art. 282. As medidas cautelares previstas neste Título deverão ser aplicadas observando-se a: 

> I - necessidade para aplicação da lei penal, para a investigação ou a instrução criminal e, nos casos expressamente previstos, para evitar a prática de infrações penais; 

> II - adequação da medida à gravidade do crime, circunstâncias do fato e condições pessoais do indiciado ou acusado. 

> §1º As medidas cautelares poderão ser aplicadas isolada ou cumulativamente. 

> § 2º As medidas cautelares serão decretadas pelo juiz, de ofício ou a requerimento das partes ou, quando no curso da investigação criminal, por representação da autoridade policial ou mediante requerimento do Ministério Público. (...)" 


O § 1º do art. 283, também do CPP, impõe que para a aplicação de qualquer medida cautelar, exige-se que a infração comine pena privativa de liberdade, isolada ou cumulativamente. "In casu", verifica-se que o suspeito fora investigado é infração penal a qual a lei comina pena privativa de liberdade. 

A doutrina elenca como pressupostos para as medidas cautelares diversas da prisão o *fumus comissi delicti*, consistente na prova da existência do crime e nos indícios de autoria, e o *periculum in mora*, consubstanciado em um dos fundamentos do art. 282, I, do CPP (a necessidade de aplicação da lei penal, para a investigação ou a instrução criminal e, nos casos expressamente previstos, para evitar a prática de infrações penais). 


O ***fumus comissi delicti*** decorre da existência de indícios suficientes de autoria e prova da materialidade, conforme procedimento investigatório apontando o denunciado como autor do desmatamento ilegal em área de preservação permanente localizada em área em que exerce a posse, conforme atesta o respectivo auto de infração. 


O ***periculum in mora*** resta demonstrado na medida em que a ordem pública encontra-se em risco em razão de: 

1. possível alteração da cena do crime (inclusive no tocante à intensificação da lesão ao bem jurídico em questão) e interferência no objeto material do crime que interessa ao processo criminal; 

2. a ordem pública, já que o livre trânsito do investigado no local do crime ambiental importará no risco (concreto) de a atividade ilícita do investigado ser mantida com novas violações ao bem jurídico ofendido com o cometimento de novas infrações penais além daquelas objeto desta investigação, primacialmente daquela prevista nos artigos 48 da Lei 9.605/98.


De fato, de maneira muito nítida, o livre trânsito do investigado no local do crime ambiental importará no risco (concreto) de a atividade ilícita do investigado ser mantida em novas violações ao bem jurídico ofendido, isto é, o direito difuso e intergeracional ao ambiente ecologicamente equilibrado para a presente e as futuras gerações, com o cometimento de novas infrações penais além daquelas objeto desta investigação, primacialmente daquela prevista no art. 48 da Lei de Crimes Ambientais:

> *“Art. 48. Impedir ou dificultar a regeneração natural de florestas e demais formas de vegetação: Pena - detenção, de seis meses a um ano, e multa.”* 

Ora, no caso, não sendo obstado o prosseguimento do crime de desmatamento ilegal estará o Estado dando azo ao prosseguimento da atividade criminosa ao permitir que o investigado venha a “impedir, dificultar e, inclusive, destruir iniciativas de recuperação natural de florestas e demais formas de vegetação”.

E não se pode negligenciar o desvalor da conduta do requerido, que está a reclamar a atuação cautelar do direito penal como ultima ratio. De fato, tamanho é o dano provocado pelos crimes ambientais que a comunidade jurídica internacional, em verdadeiro marco histórico, recentemente reconheceu que os crimes ambientais são crimes contra a humanidade, a exigir proteção no Tribunal Penal Internacional. Conforme artigo na Revista Consultor Jurídico: 

> "O Tribunal Penal Internacional anunciou, no dia 15 de setembro, que passará a processar e julgar crimes ambientais. Em documento de 18 páginas que anuncia as prioridades para a seleção de casos pela corte, o gabinete do procurador explicitou que a corte dará especial atenção a crimes relacionados à destruição do meio ambiente, à exploração de recursos naturais e à apropriação ilegal de terras. 
Essa notícia é de extrema importância para o Direito Internacional Ambiental por três motivos centrais: primeiro, porque não há, hoje, corte internacional exclusivamente dedicada à matéria ambiental; segundo, porque o acesso de atores não-estatais – seja como autores ou réus – às cortes internacionais de competências diversas que apreciam também casos ambientais é ainda significativamente limitado; e, terceiro, porque é vital que a proteção internacional do meio ambiente seja compreendida como preocupação comum da humanidade, ou seja, como parte de um conjunto de valores fundamentais dos quais a coesão da sociedade depende. O anúncio do TPI é um importante avanço nessas três frentes. O tribunal é vocacionado, nos termos do Estatuto de Roma, a julgar crimes de genocídio, crimes contra a humanidade, crimes de guerra e, a depender de ratificação, crimes de agressão.

> A expansão de seu foco para incluir crimes ambientais entre os casos que priorizará deixa claro que a comunidade internacional passará a contar com uma corte internacional permanente para, ainda que não exclusivamente, julgar crimes ambientais. (...)

> O anúncio do TPI deve ser saudado como um marco no que diz respeito a essas questões. Abrem-se portas para o julgamento de crimes que afetam comunidades inteiras – como a grilagem de terras –, bem como aqueles que são transfronteiriços por natureza e afetam a população global como um todo – como os relacionados às mudanças climáticas. Dado, porém, que na maioria das vezes esses crimes são cometidos por empresas, o mandato do TPI apresenta importante limitação na medida em que, sob o princípio da responsabilidade penal individual estabelecido no artigo 25 do Estatuto de Roma, pessoas jurídicas não estão sujeitas à sua jurisdição. (...) 

> Restrições à parte, a implicação mais relevante do anúncio do TPI reside talvez não em um aspecto prático, mas no reforço da noção de que o meio ambiente constitui uma preocupação comum da humanidade; de que as normas destinadas à sua proteção são jus cogens; e de que o interesse no seu cumprimento e aplicação é erga omnes. O policy paper do TPI não acrescenta propriamente uma nova competência àquelas constantes do Estatuto de Roma, de modo que é forçoso concluir que a anunciada priorização de crimes ambientais se insere naquela já existente para processar e julgar crimes contra a humanidade."

[NEWPAR]

Em razão do exposto, em relação às medidas cautelares diversas da prisão, o MINISTÉRIO PÚBLICO DO ESTADO DE MATO GROSSO, por seu promotor de Justiça que esta subscreve, **requer a aplicação, em desfavor da parte requerida, de MEDIDA CAUTELAR DIVERSA DA PRISÃO DE PROIBIÇÃO DE EXERCÍCIO DE ATIVIDADES ECONÔMICAS NO LOCAL DO CRIME AMBIENTAL** consistente na **suspensão do exercício de quaisquer atividades de natureza econômica (inclusive mediante interposta pessoa) sobre a área de crime ambiental** em razão do justo receio de sua utilização para a prática de infrações penais (art. 319, VI, do CPP) e, ainda, alteração do local do crime;



